==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>Icona dimensione:</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--exact match--
--file: photivo_it.ts--
PPM
Mappa X Pixel</translatorcomment>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--exact match--
--file: draft_it.ts--
Spaziatura Griglia minima (px)
Spaziatura Griglia minima (px):</translatorcomment>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translation>Colonne:</translation>
    </message>
    <message>
        <location filename="../CadToolBar.js" line="+49"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>Barra degli strumenti CAD</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Toggle Title Bar</source>
        <translation>Mostra barra del titolo</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Barra degli strumenti CAD</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+76"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>Icona dimensione:</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--exact match--
--file: photivo_it.ts--
PPM
Mappa X Pixel</translatorcomment>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--exact match--
--file: draft_it.ts--
Spaziatura Griglia minima (px)
Spaziatura Griglia minima (px):</translatorcomment>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translation>Colonne:</translation>
    </message>
    <message>
        <location filename="../CadToolBar.js" line="+51"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>Barra degli strumenti CAD</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Vertical/Horizontal</source>
        <translation>Verticale / Orizzontale</translation>
    </message>
    <message>
        <source>Toggle Title Bar</source>
        <translation type="vanished">Mostra barra del titolo</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Barra degli strumenti CAD</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+107"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
</context>
</TS>
